package com.pranjal.calendarnotificationprovider;

import android.content.Context;
import android.content.SharedPreferences;
import android.provider.SyncStateContract;
import android.util.Log;

import androidx.annotation.NonNull;

import com.google.gson.Gson;
import com.pranjal.calendarnotificationprovider.models.Constants2;
import com.pranjal.calendarnotificationprovider.models.DynamicText;
import com.pranjal.calendarnotificationprovider.models.EventKeys;
import com.pranjal.calendarnotificationprovider.models.SharedPrefKeys;

import java.util.ArrayList;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.embedding.engine.plugins.broadcastreceiver.BroadcastReceiverAware;
import io.flutter.embedding.engine.plugins.broadcastreceiver.BroadcastReceiverPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** CalendarnotificationproviderPlugin */
public class CalendarnotificationproviderPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware, BroadcastReceiverAware  {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private static SharedPreferences sharedPreferences;
  SharedPrefsManager prefsManager;
  private static final String TAG = "Calendarnotificationpro";
  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "calendarnotificationprovider");
    Context context = flutterPluginBinding.getApplicationContext();
    prefsManager = new SharedPrefsManager(context,context.getPackageName(),0);
    //sharedPreferences = flutterPluginBinding.getApplicationContext().getSharedPreferences("abcd",0);
    channel.setMethodCallHandler(this);
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "calendarnotificationprovider");
    channel.setMethodCallHandler(new CalendarnotificationproviderPlugin());
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
      Object args = call.arguments;
      switch (call.method){
        case "getPlatformVersion":
          result.success("Android " + android.os.Build.VERSION.RELEASE);
          break;
        case "setPackageName":
          prefsManager.setPreferences(Constants2.sharedPrefKeys.get(SharedPrefKeys.PackageName),args.toString());
          break;
        case "setAppOpenName":
          prefsManager.setPreferences(Constants2.sharedPrefKeys.get(SharedPrefKeys.OnClickAppName),args.toString());
          break;
        case "setDescription":
          String data = new Gson().toJson(new DynamicText(((ArrayList) args).get(0).toString(), getEventKeyFromString(((ArrayList) args).get(1).toString()),((ArrayList) args).get(2).toString()));
          prefsManager.setPreferences(Constants2.sharedPrefKeys.get(SharedPrefKeys.description),data);
          break;
        case "setTitle":
          String data2 = new Gson().toJson(new DynamicText(((ArrayList) args).get(0).toString(), getEventKeyFromString(((ArrayList) args).get(1).toString()),((ArrayList) args).get(2).toString()));
          prefsManager.setPreferences(Constants2.sharedPrefKeys.get(SharedPrefKeys.title),data2);
          break;
        case "setSmallIcon":
          prefsManager.setPreferences(Constants2.sharedPrefKeys.get(SharedPrefKeys.smallIcon),args.toString());
          break;
        case "setLargeIcon":
          prefsManager.setPreferences(Constants2.sharedPrefKeys.get(SharedPrefKeys.largeIcon),args.toString());
          break;
        default:
          result.notImplemented();
      }
//    if (call.method.equals("getPlatformVersion")) {
//      result.success("Android " + android.os.Build.VERSION.RELEASE);
//    } else if(call.method.equals("setPackageName")){
//      SharedPreferences.Editor editor = sharedPreferences.edit();
//      editor.putString("abcd", "com.example.app");
//      editor.apply();
//    }else {
//      result.notImplemented();
//    }
  }

  private EventKeys getEventKeyFromString(String a){
    switch (a){
      case "Title":
        return EventKeys.Title;
      case "imeLeft":
        return EventKeys.TimeLeft;
      case "RangeTime":
        return EventKeys.RangeTime;
      case "Description":
        return EventKeys.Description;
    }
    return EventKeys.Title;
  }

  static String getPackageName(){
    return sharedPreferences.getString("abcd","");
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding activityPluginBinding) {

  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding activityPluginBinding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }

  @Override
  public void onAttachedToBroadcastReceiver(BroadcastReceiverPluginBinding broadcastReceiverPluginBinding) {
    Log.d(TAG, "onAttachedToBroadcastReceiver: attached to br");
  }

  @Override
  public void onDetachedFromBroadcastReceiver() {

  }
}
